@@ -1,3 +1,10 @@
+'''
+Pictures demo
+=============
+
+This is a basic picture viewer, using the scatter widget.
+'''
+
 import kivy
 kivy.require('1.0.6')
 
@@ -13,6 +20,13 @@ from kivy.core.window import Window
 
 
 class Picture(Scatter):
+    '''Picture is the class that will show the image with a white border and a
+    shadow. They are nothing here because almost everything is inside the
+    picture.kv. Check the rule named <Picture> inside the file, and you'll see
+    how the Picture() is really constructed and used.
+
+    The source property will be the filename to show.
+    '''
 
     source = StringProperty(None)
 
