@@ -23,6 +23,15 @@ Change the configuration and save it::
 Available configuration tokens
 ------------------------------
 
+.. versionchanged:: 1.0.8
+
+    * `scroll_timeout`, `scroll_distance` and `scroll_friction` have been added
+    * `list_friction`, `list_trigger_distance` and `list_friction_bound` have
+      been removed.
+    * `keyboard_type` and `keyboard_layout` have been removed from widget
+    * `keyboard_mode` and `keyboard_layout` have been added to kivy section
+
+
 :kivy:
 
     `log_level`: (debug, info, warning, error, critical)
@@ -33,6 +42,13 @@ Available configuration tokens
         Format string to use for the filename of log file
     `log_enable`: (0, 1)
         Activate file logging
+    `keyboard_mode`: ('', 'system', 'dock', 'multi')
+        Keyboard mode to use. If empty, Kivy will decide for you what is the
+        best for your current platform. Otherwise, you can set one of 'system'
+        (real keyboard), 'dock' (one virtual keyboard docked in a screen side),
+        'multi' (one virtual keyboard everytime a widget ask for.)
+    `keyboard_layout`: string
+        Identifier of the layout to use
 
 :postproc:
 
@@ -114,22 +130,20 @@ Available configuration tokens
 
 :widgets:
 
-    `list_trigger_distance`: int
-        Maximum distance to trigger the on_touch_down/on_touch_up on child for
-        every :class:`~kivy.uix.list.List` widget. The value is in pixels.
+    `scroll_distance`: int
+        Default value of :data:`~kivy.uix.scrollview.Scrollview.scroll_distance`
+        property in :class:`~kivy.uix.scrollview.Scrollview` widget.
+        Check the widget documentation for more information.
 
-    `list_friction`: int
-        Friction factor. 1 mean no friction.
+    `scroll_friction`: float
+        Default value of :data:`~kivy.uix.scrollview.Scrollview.scroll_friction`
+        property in :class:`~kivy.uix.scrollview.Scrollview` widget.
+        Check the widget documentation for more information.
 
-    `list_friction_bound`: int
-        If one side of the list have been hit by the user, you have the
-        possibility to reduce the friction to use. Prefer a value below the
-        `list_friction` token.
-
-    `keyboard_type`: (real, virtual)
-        Type of the keyboard to use.
-        If set to `real`, no virtual keyboard will be shown on the screen.
-        You will have to use your hardware keyboard to enter text.
+    `scroll_timeout`: int
+        Default value of :data:`~kivy.uix.scrollview.Scrollview.scroll_timeout`
+        property in :class:`~kivy.uix.scrollview.Scrollview` widget.
+        Check the widget documentation for more information.
 
 :modules:
 
@@ -150,10 +164,10 @@ from os import environ, listdir
 from os.path import exists, join
 from kivy import kivy_home_dir, kivy_config_fn, kivy_data_dir
 from kivy.logger import Logger
-from kivy.utils import OrderedDict, QueryDict
+from kivy.utils import OrderedDict
 
 # Version number of current configuration format
-KIVY_CONFIG_VERSION = 3
+KIVY_CONFIG_VERSION = 5
 
 #: Kivy configuration object
 Config = None
@@ -319,7 +333,7 @@ if not 'KIVY_DOC_INCLUDE' in environ:
 
             # default configuration for keyboard repeatition
             Config.setdefault('widgets', 'keyboard_layout', 'qwerty')
-            Config.setdefault('widgets', 'keyboard_type', 'virtual')
+            Config.setdefault('widgets', 'keyboard_type', '')
             Config.setdefault('widgets', 'list_friction', '10')
             Config.setdefault('widgets', 'list_friction_bound', '20')
             Config.setdefault('widgets', 'list_trigger_distance', '5')
@@ -338,7 +352,26 @@ if not 'KIVY_DOC_INCLUDE' in environ:
                 logo_size = 512
             Config.set('kivy', 'window_icon', \
                 join(kivy_home_dir, 'icon', 'kivy-icon-%d.png' % logo_size))
-        #
+
+        elif version == 3:
+            # add token for scrollview
+            Config.setdefault('widgets', 'scroll_timeout', '250')
+            Config.setdefault('widgets', 'scroll_distance', '20')
+            Config.setdefault('widgets', 'scroll_friction', '1.')
+
+            # remove old list_* token
+            Config.remove_option('widgets', 'list_friction')
+            Config.remove_option('widgets', 'list_friction_bound')
+            Config.remove_option('widgets', 'list_trigger_distance')
+
+        elif version == 4:
+            Config.remove_option('widgets', 'keyboard_type')
+            Config.remove_option('widgets', 'keyboard_layout')
+
+            # add keyboard token
+            Config.setdefault('kivy', 'keyboard_mode', '')
+            Config.setdefault('kivy', 'keyboard_layout', 'qwerty')
+
         #elif version == 1:
         #   # add here the command for upgrading from configuration 0 to 1
         #
@@ -359,6 +392,7 @@ if not 'KIVY_DOC_INCLUDE' in environ:
     # If no configuration exist, write the default one.
     if not exists(kivy_config_fn) or need_save:
         try:
+            Config.filename = kivy_config_fn
             Config.write()
         except Exception, e:
             Logger.exception('Core: Error while saving default config file')
