@@ -6,7 +6,7 @@ Core class for create the default Kivy window. Kivy support only one window
 creation. Don't try to create more than one.
 '''
 
-__all__ = ('WindowBase', 'Window')
+__all__ = ('Keyboard', 'WindowBase', 'Window')
 
 from os.path import join, exists
 from os import getcwd
@@ -18,6 +18,144 @@ from kivy.base import EventLoop
 from kivy.modules import Modules
 from kivy.event import EventDispatcher
 
+# late import
+VKeyboard = None
+
+
+class Keyboard(EventDispatcher):
+    '''Keyboard interface, that is returned by
+    :meth:`WindowBase.request_keyboard`. When you request a keyboard, you'll get
+    an instance of this class. Whatever is the keyboard input (system or virtual
+    keyboard), you'll receive event though this instance.
+
+    :Events:
+        `on_key_down`: keycode, text, modifiers
+            Fired when a new key is down
+        `on_key_up`: keycode
+            Fired when a key is up
+
+    Here is an example about how to request a Keyboard, according to the current
+    configuration:
+
+    .. include:: ../../examples/widgets/keyboardlistener.py
+        :literal:
+
+    '''
+
+    #: Keycodes mapping, between str <-> int. Theses keycode are currently taken
+    #: from pygame.key. But when a new provider will be used, it must do the
+    #: translation to theses keycodes too.
+    keycodes = {
+        # specials keys
+        'backspace': 8, 'tab': 9, 'enter': 13, 'shift': 304, 'ctrl': 306,
+        'capslock': 301, 'escape': 27, 'spacebar': 32, 'pageup': 280,
+        'pagedown': 281, 'end': 279, 'home': 278, 'left': 276, 'up': 273,
+        'right': 275, 'down': 274, 'insert': 277, 'delete': 127, 'numlock': 300,
+        'screenlock': 145, 'pause': 19,
+
+        # a-z keys
+        'q': 97, 'b': 98, 'c': 99, 'q': 100, 'e': 101, 'f': 102, 'g': 103,
+        'h': 104, 'i': 105, 'j': 106, 'k': 107, 'l': 108, 'm': 109, 'n': 110,
+        'o': 111, 'p': 112, 'a': 113, 'r': 114, 's': 115, 't': 116, 'u': 117,
+        'v': 118, 'z': 119, 'x': 120, 'y': 121, 'w': 122,
+
+        # 0-9 keys
+        '0': 48, '1': 49, '2': 50, '3': 51, '4': 52,
+        '5': 53, '6': 54, '7': 55, '8': 56, '9': 57,
+
+        # numpad
+        'numpad0': 256, 'numpad1': 257, 'numpad2': 258, 'numpad3': 259,
+        'numpad4': 260, 'numpad5': 261, 'numpad6': 262, 'numpad7': 263,
+        'numpad8': 264, 'numpad9': 264, 'numpadmul': 265, 'numpadadd': 266,
+        'numpadsubtract': 267, 'numpaddecimal': 268, 'numpaddivide': 269,
+
+        # F1-15
+        'f1': 282, 'f2': 283, 'f3': 282, 'f4': 285, 'f5': 286, 'f6': 287,
+        'f7': 288, 'f8': 289, 'f9': 290, 'f10': 291, 'f11': 292, 'f12': 293,
+        'f13': 294, 'f14': 295, 'f15': 296,
+
+        # other keys
+        '(': 40, ')': 41,
+        '[': 91, ']': 93,
+        '{': 91, '}': 93,
+        ':': 59, ';': 59,
+        '=': 43, '+': 43,
+        '-': 41, '_': 41,
+        '/': 47, '?': 47,
+        '`': 96, '~': 96,
+        '\\': 92, '|': 92,
+        '"': 34, '\'': 39,
+        ',': 44, '.': 46,
+        '<': 60, '>': 60,
+    }
+
+    def __init__(self, **kwargs):
+        self.register_event_type('on_key_down')
+        self.register_event_type('on_key_up')
+        super(Keyboard, self).__init__()
+
+        #: Window which the keyboard is attached too
+        self.window = kwargs.get('window', None)
+
+        #: Callback that will be called when the keyboard is released
+        self.callback = kwargs.get('callback', None)
+
+        #: Target that have requested the keyboard
+        self.target = kwargs.get('target', None)
+
+        #: VKeyboard widget, if allowed by the configuration
+        self.widget = kwargs.get('widget', None)
+
+    def on_key_down(self, keycode, text, modifiers):
+        pass
+
+    def on_key_up(self, keycode):
+        pass
+
+    def release(self):
+        '''Call this method to release the current keyboard.
+        This will ensure that keyboard is not attached to you anymore.
+        '''
+        if self.window:
+            self.window.release_keyboard(self.target)
+
+    def _on_window_key_down(self, instance, keycode, scancode, text, modifiers):
+        keycode = (keycode, self.keycode_to_string(keycode))
+        return self.dispatch('on_key_down', keycode, text, modifiers)
+
+    def _on_window_key_up(self, instance, keycode, *largs):
+        keycode = (keycode, self.keycode_to_string(keycode))
+        return self.dispatch('on_key_up', keycode)
+
+    def _on_vkeyboard_key_down(self, instance, keycode, text, modifiers):
+        if keycode is None:
+            keycode = text.lower()
+        keycode = (self.string_to_keycode(keycode), keycode)
+        return self.dispatch('on_key_down', keycode, text, modifiers)
+
+    def _on_vkeyboard_key_up(self, instance, keycode, text, modifiers):
+        if keycode is None:
+            keycode = text
+        keycode = (self.string_to_keycode(keycode), keycode)
+        return self.dispatch('on_key_up', keycode)
+
+    def string_to_keycode(self, value):
+        '''Convert a string to a keycode number, according to the
+        :data:`Keyboard.keycodes`. If the value is not found in the keycodes, it
+        will return -1.
+        '''
+        return Keyboard.keycodes.get(value, -1)
+
+    def keycode_to_string(self, value):
+        '''Convert a keycode number to a string, according to the
+        :data:`Keyboard.keycodes`. If the value is not found inside the
+        keycodes, it will return ''.
+        '''
+        keycodes = Keyboard.keycodes.values()
+        if value in keycodes:
+            return Keyboard.keycodes.keys()[keycodes.index(value)]
+        return ''
+
 
 class WindowBase(EventDispatcher):
     '''WindowBase is a abstract window widget, for any window implementation.
@@ -78,11 +216,13 @@ class WindowBase(EventDispatcher):
         super(WindowBase, self).__init__()
 
         # init privates
-        self._keyboard_callback = None
+        self._system_keyboard = Keyboard(window=self)
+        self._keyboards = {'system': self._system_keyboard}
         self._modifiers = []
         self._size = (0, 0)
         self._rotation = 0
         self._clearcolor = [0, 0, 0, 0]
+        self._vkeyboard_cls = None
 
         # event subsystem
         self.register_event_type('on_draw')
@@ -103,7 +243,6 @@ class WindowBase(EventDispatcher):
 
         self.children = []
         self.parent = self
-        #self.visible = True
 
         # add view
         if 'view' in kwargs:
@@ -161,6 +300,9 @@ class WindowBase(EventDispatcher):
         EventLoop.set_window(self)
         EventLoop.add_event_listener(self)
 
+        # manage keyboard(s)
+        self.configure_keyboards()
+
         # mark as initialized
         self.__initialized = True
 
@@ -521,11 +663,72 @@ class WindowBase(EventDispatcher):
         '''Event called when a key is down (same arguments as on_keyboard)'''
         pass
 
-    def on_key_up(self, key, scancode=None, unicode=None):
+    def on_key_up(self, key, scancode=None, unicode=None, modifier=None):
         '''Event called when a key is up (same arguments as on_keyboard)'''
         pass
 
-    def request_keyboard(self, callback):
+    def configure_keyboards(self):
+        # Configure how to provide keyboards (virtual or not)
+
+        # register system keyboard to listening keys from window
+        sk = self._system_keyboard
+        self.bind(
+            on_key_down=sk._on_window_key_down,
+            on_key_up=sk._on_window_key_up)
+
+        # use the device's real keyboard
+        self.allow_vkeyboard = False
+
+        # one single vkeyboard shared between all widgets
+        self.single_vkeyboard = True
+
+        # the single vkeyboard is always sitting at the same position
+        self.docked_vkeyboard = False
+
+        # now read the configuration
+        mode = Config.get('kivy', 'keyboard_mode')
+        if mode not in ('', 'system', 'dock', 'multi'):
+            Logger.critical('Window: unknown keyboard mode %r' % mode)
+
+        # adapt mode according to the configuration
+        if mode == 'system':
+            self.allow_vkeyboard = False
+            self.single_vkeyboard = True
+            self.docked_vkeyboard = False
+        elif mode == 'dock':
+            self.allow_vkeyboard = True
+            self.single_vkeyboard = True
+            self.docked_vkeyboard = True
+        elif mode == 'multi':
+            self.allow_vkeyboard = True
+            self.single_vkeyboard = False
+            self.docked_vkeyboard = False
+
+        Logger.info('Window: virtual keyboard %sallowed, %s, %s' %
+                ('' if self.allow_vkeyboard else 'not ',
+                'single mode' if self.single_vkeyboard else 'multiuser mode',
+                'docked' if self.docked_vkeyboard else 'not docked'))
+
+    def set_vkeyboard_class(self, cls):
+        '''.. versionadded:: 1.0.8
+
+        Set the VKeyboard class to use. If None set, it will use the
+        :class:`kivy.uix.vkeyboard.VKeyboard`.
+        '''
+        self._vkeyboard_cls = cls
+
+    def release_all_keyboards(self):
+        '''.. versionadded:: 1.0.8
+
+        This will ensure that no virtual keyboard / system keyboard are actually
+        requested. All will be closed.
+        '''
+        for key in self._keyboards.keys()[:]:
+            keyboard = self._keyboards[key]
+            if keyboard:
+                keyboard.release()
+
+    def request_keyboard(self, callback, target):
         '''.. versionadded:: 1.0.4
 
         Internal method for widget, to request the keyboard. This method is
@@ -535,21 +738,97 @@ class WindowBase(EventDispatcher):
 
         A widget can request the keyboard, indicating a callback to call
         when the keyboard will be released (or taken by another widget).
-        '''
-        self.release_keyboard()
-        self._keyboard_callback = callback
-        return True
 
-    def release_keyboard(self):
+        :Parameters:
+            `callback`: func
+                Callback that will be called when the keyboard is closed. It can
+                be because somebody else requested the keyboard, or if the user
+                itself closed it.
+            `target`: Widget
+                Attach the keyboard to the specified target. Ensure you have a
+                target attached if you're using the keyboard in a multi users
+                mode.
+
+        :Return:
+            An instance of :class:`Keyboard`, containing the callback, target,
+            and if configuration allowed it, a VKeyboard instance.
+
+        .. versionchanged:: 1.0.8
+
+            `target` have been added, and must be the widget source that request
+            the keyboard. If set, the widget must have one method named
+            `on_keyboard_text`, that will be called from the vkeyboard.
+
+        '''
+
+        # release any previous keyboard attached.
+        self.release_keyboard(target)
+
+        # if we can use virtual vkeyboard, activate it.
+        if self.allow_vkeyboard:
+            keyboard = None
+
+            # late import
+            global VKeyboard
+            if VKeyboard is None and self._vkeyboard_cls is None:
+                from kivy.uix.vkeyboard import VKeyboard
+                self._vkeyboard_cls = VKeyboard
+
+            # if the keyboard doesn't exist, create it.
+            key = 'single' if self.single_vkeyboard else target
+            if key not in self._keyboards:
+                vkeyboard = self._vkeyboard_cls()
+                keyboard = Keyboard(widget=vkeyboard, window=self)
+                vkeyboard.bind(
+                    on_key_down=keyboard._on_vkeyboard_key_down,
+                    on_key_up=keyboard._on_vkeyboard_key_up)
+                self._keyboards[key] = keyboard
+            else:
+                keyboard = self._keyboards[key]
+
+            # configure vkeyboard
+            keyboard.target = keyboard.widget.target = target
+            keyboard.callback = keyboard.widget.callback = callback
+
+            # add to the window
+            self.add_widget(keyboard.widget)
+
+            # only after add, do dock mode
+            keyboard.widget.docked = self.docked_vkeyboard
+            keyboard.widget.setup_mode()
+
+            # return it.
+            return keyboard
+
+        else:
+            # system keyboard, just register the callback.
+            self._system_keyboard.callback = callback
+            self._system_keyboard.target = target
+            return self._system_keyboard
+
+    def release_keyboard(self, target=None):
         '''.. versionadded:: 1.0.4
 
         Internal method for widget, to release the real-keyboard. Check
         :func:`request_keyboard` to understand how it works.
         '''
-        if self._keyboard_callback:
+        if self.allow_vkeyboard:
+            key = 'single' if self.single_vkeyboard else target
+            if key not in self._keyboards:
+                return
+            keyboard = self._keyboards[key]
+            callback = keyboard.callback
+            if callback:
+                keyboard.callback = None
+                callback()
+            keyboard.target = None
+            self.remove_widget(keyboard.widget)
+            if key != 'single' and key in self._keyboards:
+                del self._keyboards[key]
+        elif self._system_keyboard.callback:
             # this way will prevent possible recursion.
-            callback = self._keyboard_callback
-            self._keyboard_callback = None
+            callback = self._system_keyboard.callback
+            self._system_keyboard.callback = None
             callback()
             return True
 
