@@ -35,6 +35,8 @@ The language consists of several constructs that you can use:
 Syntax of a kv File
 -------------------
 
+.. highlight:: kv
+
 A Kivy language file must have ``.kv`` as filename extension.
 
 The content of the file must always start with the Kivy header, where `version`
@@ -43,25 +45,25 @@ must be replaced with the Kivy language version you're using. For now, use
 
     #:kivy `version`
 
-    `content`
+    # content here
 
 The `content` can contain rule definitions, a root widget and templates::
 
     # Syntax of a rule definition. Note that several Rules can share the same
     # definition (as in CSS). Note the braces; They are part of the definition.
     <Rule1,Rule2>:
-        .. definitions ..
+        # .. definitions ..
 
     <Rule3>:
-        .. definitions ..
+        # .. definitions ..
 
     # Syntax for creating a root widget
     RootClassName:
-        .. definitions ..
+        # .. definitions ..
 
     # Syntax for create a template
     [TemplateName@BaseClass1,BaseClass2]:
-        .. definitions ..
+        # .. definitions ..
 
 Regardless of whether it's a rule, root widget or template you're defining,
 the definition should look like this::
@@ -201,7 +203,7 @@ in processing order (i.e. top-down).
 If you want to change how Buttons are rendered, you can create your own kv file
 and put something like this::
 
-    <Button>
+    <Button>:
         canvas:
             Color:
                 rgb: (1, 0, 0)
@@ -217,7 +219,7 @@ This will result in buttons having a red background, with the label in the
 bottom left, in addition to all the preceding rules.
 You can clear all the previous instructions by using the `Clear` command::
 
-    <Button>
+    <Button>:
         canvas:
             Clear
             Color:
@@ -253,11 +255,11 @@ Syntax of a template::
 
     # With only one base class
     [ClassName@BaseClass]:
-        .. definitions ..
+        # .. definitions ..
 
     # With more than one base class
     [ClassName@BaseClass1,BaseClass2]:
-        .. definitions ..
+        # .. definitions ..
 
 For example, for a list, you'll need to create a entry with a image on the left,
 and a label on the right. You can create a template for making that definition
@@ -271,13 +273,17 @@ filename and a title ::
         Label:
             text: ctx.title
 
+.. highlight:: python
+
 Then in Python, you can create instanciate the template with ::
 
     from kivy.lang import Builder
 
     # create a template with hello world + an image
-    # the context values should be passed as kwargs to the Builder.template function
-    icon1 = Builder.template('IconItem', title='Hello world', image='myimage.png')
+    # the context values should be passed as kwargs to the Builder.template
+    # function
+    icon1 = Builder.template('IconItem', title='Hello world',
+        image='myimage.png')
 
     # create a second template with another information
     ctx = {'title': 'Another hello world',
@@ -289,6 +295,8 @@ Then in Python, you can create instanciate the template with ::
 Template example
 ~~~~~~~~~~~~~~~~
 
+.. highlight:: kv
+
 Most of time, when you are creating screen into kv lang, you have lot of
 redefinition. In our example, we'll create a Toolbar, based on a BoxLayout, and
 put many Image that will react to on_touch_down::
@@ -439,16 +447,52 @@ import re
 import sys
 from os.path import join
 from copy import copy
-from types import ClassType
+from types import ClassType, CodeType
 from functools import partial
 from kivy.factory import Factory
 from kivy.logger import Logger
 from kivy.utils import OrderedDict, QueryDict
+from kivy.cache import Cache
 from kivy import kivy_data_dir
 
 trace = Logger.trace
 global_idmap = {}
 
+# register cache for creating new classtype (template)
+Cache.register('kv.lang')
+
+# precompile regexp expression
+lang_str = re.compile('([\'"][^\'"]*[\'"])')
+lang_key = re.compile('([a-zA-Z_]+)')
+lang_keyvalue = re.compile('([a-zA-Z_][a-zA-Z0-9_.]*\.[a-zA-Z0-9_.]+)')
+
+
+def precompile_value(name, value):
+    # if it's an id, we don't need to compile, the value is the id.
+    if name == 'id':
+        return value
+    # first, remove all the string from the value
+    tmp = re.sub(lang_str, '', value)
+
+    # detecting how to handle the value according to the key name
+    mode = 'exec' if name.startswith('on_') else 'eval'
+    if mode == 'eval':
+        # if we don't detect any string/key in it, we can eval and give the
+        # result
+        if re.search(lang_key, tmp) is None:
+            return (None, eval(value), value)
+
+    # ok, we can compile.
+    code = compile(value, '<string>', mode)
+
+    # now, detect obj.prop
+    # first, remove all the string from the value
+    tmp = re.sub(lang_str, '', value)
+    # detect key.value inside value
+    kw = re.findall(lang_keyvalue, tmp)
+
+    return (kw, code, value)
+
 
 class ParserError(Exception):
 
@@ -678,6 +722,7 @@ class Parser(object):
                         raise ParserError(self, ln, 'Syntax error')
                     value = x[1].strip()
                     if len(value):
+                        value = precompile_value(name, value)
                         current_object[name] = (value, ln, self)
                     else:
                         current_property = name
@@ -735,31 +780,24 @@ def custom_callback(*largs, **kwargs):
     element, key, value, idmap = largs[0]
     locals().update(idmap)
     args = largs[1:]
-    exec value
+    exec value[1]
 
 
-def create_handler(element, key, value, idmap):
-    # first, remove all the string from the value
-    tmp = re.sub('([\'"][^\'"]*[\'"])', '', value)
-
-    # detect key.value inside value
-    kw = re.findall('([a-zA-Z_][a-zA-Z0-9_.]*\.[a-zA-Z0-9_.]+)', tmp)
-    if not kw:
-        # look like no reference, just pass it
-        return eval(value, _eval_globals, idmap)
+def create_handler(element, key, vd, idmap):
+    kw = vd[0]
+    value = vd[1]
+    assert(kw is not None)
 
     # create an handler
     idmap = copy(idmap)
 
-    c_value = compile(value, '<string>', 'eval')
-
     def call_fn(sender, _value):
         if __debug__:
-            trace('Builder: call_fn %s, key=%s, value=%s' % (
+            trace('Builder: call_fn %s, key=%s, value=%r' % (
                 element, key, value))
-        e_value = eval(c_value, _eval_globals, idmap)
+        e_value = eval(value, _eval_globals, idmap)
         if __debug__:
-            trace('Builder: call_fn => value=%s' % str(e_value))
+            trace('Builder: call_fn => value=%r' % (e_value, ))
         setattr(element, key, e_value)
 
     # bind every key.value
@@ -849,17 +887,20 @@ class BuilderBase(object):
         self.listwidgets = []
         self.listwidget = []
 
+        # rules and templates will be associated to current loaded file
+        self._current_filename = None
+
     def add_rule(self, rule, defs):
         if __debug__:
             trace('Builder: adding rule %s' % str(rule))
-        self.rules.append((rule, defs))
+        self.rules.append((rule, defs, self._current_filename))
 
     def add_template(self, name, cls, defs):
         if __debug__:
             trace('Builder: adding template %s' % str(name))
         if name in self.templates:
             raise Exception('The template <%s> already exist' % name)
-        self.templates[name] = (cls, defs)
+        self.templates[name] = (cls, defs, self._current_filename)
 
     def load_file(self, filename, **kwargs):
         '''Insert a file into the language builder.
@@ -875,6 +916,25 @@ class BuilderBase(object):
             kwargs['filename'] = filename
             return self.load_string(fd.read(), **kwargs)
 
+    def unload_file(self, filename):
+        '''Unload all rules associated to a previously imported file.
+
+        .. versionadded:: 1.0.8
+
+        .. warning::
+
+            This will not remove rule or template already applied/used on
+            current widget. It will act only for the next widget creation or
+            template invocation.
+        '''
+        # remove rules and templates
+        self.rules = [x for x in self.rules if x[2] != filename]
+        templates = {}
+        for x, y in self.templates.iteritems():
+            if y[2] != filename:
+                templates[x] = y
+        self.templates = templates
+
     def load_string(self, string, **kwargs):
         '''Insert a string into the Language Builder
 
@@ -884,19 +944,23 @@ class BuilderBase(object):
                 widget inside the definition.
         '''
         kwargs.setdefault('rulesonly', False)
-        parser = Parser(content=string)
-        root = self.build(parser.objects)
-        if kwargs['rulesonly'] and root:
-            filename = kwargs.get('rulesonly', '<string>')
-            raise Exception('The file <%s> contain also non-rules '
-                            'directives' % filename)
+        self._current_filename = kwargs.get('filename', None)
+        try:
+            parser = Parser(content=string)
+            root = self.build(parser.objects)
+            if kwargs['rulesonly'] and root:
+                filename = kwargs.get('rulesonly', '<string>')
+                raise Exception('The file <%s> contain also non-rules '
+                                'directives' % filename)
+        finally:
+            self._current_filename = None
         return root
 
     def match(self, widget):
         '''Return a list of all rules matching the widget.
         '''
         matches = []
-        for rule, defs in self.rules:
+        for rule, defs, fn in self.rules:
             if rule.match(widget):
                 matches.append(defs)
         return matches
@@ -931,11 +995,16 @@ class BuilderBase(object):
         name = args[0]
         if not name in self.templates:
             raise Exception('Unknown <%s> template name' % name)
-        baseclasses, defs = self.templates[name]
-        rootwidgets = []
-        for basecls in baseclasses.split('+'):
-            rootwidgets.append(Factory.get(basecls))
-        cls = ClassType(name, tuple(rootwidgets), {})
+        baseclasses, defs, fn = self.templates[name]
+        name, baseclasses
+        key = '%s|%s' % (name, baseclasses)
+        cls = Cache.get('kv.lang', key)
+        if cls is None:
+            rootwidgets = []
+            for basecls in baseclasses.split('+'):
+                rootwidgets.append(Factory.get(basecls))
+            cls = ClassType(name, tuple(rootwidgets), {})
+            Cache.append('kv.lang', key, cls)
         widget = cls()
         self._push_widgets()
         self._push_ids()
@@ -1011,7 +1080,7 @@ class BuilderBase(object):
                 raise ParserError(params['__ctx__'], params['__line__'],
                                'Rules are not accepted inside widgets')
             no_apply = False
-            if item.startswith('+'):
+            if item[0] == '+':
                 item = item[1:]
                 no_apply = True
 
@@ -1048,7 +1117,7 @@ class BuilderBase(object):
                     raise ParserError(params['__ctx__'], params['__line__'],
                            'Canvas instruction in template are forbidden')
                 try:
-                    ctx[key] = eval(value[0], _eval_globals, self.idmap)
+                    ctx[key] = eval(value[0][2], _eval_globals, self.idmap)
                 except Exception, e:
                     raise ParserError(params['__ctx__'], params['__line__'], e)
             widget = cls(**ctx)
@@ -1135,7 +1204,10 @@ class BuilderBase(object):
                 element, key, value, idmap))})
 
         else:
-            value = create_handler(element, key, value, idmap)
+            if type(value[1]) is CodeType:
+                value = create_handler(element, key, value, idmap)
+            else:
+                value = value[1]
             if __debug__:
                 trace('Builder: set %s=%s for %s' % (key, value, element))
             if is_widget and not hasattr(element, key):
