@@ -7,7 +7,7 @@ offering you 2 functions for searching specific resources across a list of
 paths.
 '''
 
-__all__ = ('resource_find', 'resource_add_path')
+__all__ = ('resource_find', 'resource_add_path', 'resource_remove_path')
 
 from os.path import join, dirname, exists
 from kivy import kivy_data_dir
@@ -45,3 +45,14 @@ def resource_add_path(path):
     Logger.debug('Resource: add <%s> in path list' % path)
     resource_paths.append(path)
 
+
+def resource_remove_path(path):
+    '''Remove a search path
+
+    .. versionadded:: 1.0.8
+    '''
+    if path not in resource_paths:
+        return
+    Logger.debug('Resource: remove <%s> from path list' % path)
+    resource_paths.remove(path)
+
