@@ -11,6 +11,7 @@ class Widget(object):
     def __init__(self, **kwargs):
         super(Widget, self).__init__(**kwargs)
         self.__dict__['__uid'] = 1
+        self.__dict__['__storage'] = {}
 
 
 wid = Widget()
@@ -211,3 +212,40 @@ class PropertiesTestCase(unittest.TestCase):
         x.set(wid, 99)
         self.assertEqual(observe_called, 1)
 
+    def test_dict(self):
+        from kivy.properties import DictProperty
+
+        x = DictProperty({})
+        x.link(wid, 'x')
+        x.link_deps(wid, 'x')
+
+        # test observer
+        global observe_called
+        observe_called = 0
+
+        def observe(obj, value):
+            global observe_called
+            observe_called = 1
+
+        x.bind(wid, observe)
+
+        observe_called = 0
+        x.get(wid)['toto'] = 1
+        self.assertEqual(observe_called, 1)
+
+        observe_called = 0
+        x.get(wid)['toto'] = 2
+        self.assertEqual(observe_called, 1)
+
+        observe_called = 0
+        x.get(wid)['youupi'] = 2
+        self.assertEqual(observe_called, 1)
+
+        observe_called = 0
+        del x.get(wid)['toto']
+        self.assertEqual(observe_called, 1)
+
+        observe_called = 0
+        x.get(wid).update({'bleh': 5})
+        self.assertEqual(observe_called, 1)
+
