@@ -5,14 +5,15 @@ Button
 .. image:: images/button.jpg
     :align: right
 
-The button is a :class:`~kivy.uix.label.Label` with an action associated to it
-that is triggered when the button is pressed (or released after a click/touch).
+:class:`Button` is a :class:`~kivy.uix.label.Label` with associated actions that
+are triggered when the button is pressed (or released after a click/touch).
 To configure the button, you can use the same properties that you can use for
 the Label class::
 
     button = Button(text='Hello world', font_size=14)
 
-Attaching a callback when the button is pressed (clicked/touched) ::
+To attach a callback when the button is pressed (clicked/touched), use 
+:class:`~kivy.uix.widget.Widget.bind` ::
 
     def callback(instance):
         print 'The button <%s> is being pressed' % instance.text
@@ -35,7 +36,7 @@ to the :data:`Button.state` property ::
 __all__ = ('Button', )
 
 from kivy.uix.label import Label
-from kivy.properties import OptionProperty, StringProperty
+from kivy.properties import OptionProperty, StringProperty, ListProperty
 
 
 class Button(Label):
@@ -50,12 +51,22 @@ class Button(Label):
     '''
 
     state = OptionProperty('normal', options=('normal', 'down'))
-    '''State of the button, can be one of 'normal' or 'down'.
-    By default, the state of the button is 'normal'.
+    '''State of the button, must be one of 'normal' or 'down'.
+    The state is 'down' only when the button is currently touched/clicked,
+    otherwise 'normal'.
 
     :data:`state` is an :class:`~kivy.properties.OptionProperty`.
     '''
 
+    background_color = ListProperty([1, 1, 1, 1])
+    '''Background color, in the format (r, g, b, a).
+
+    .. versionadded:: 1.0.8
+
+    :data:`background_color` is a :class:`~kivy.properties.ListProperty`,
+    default to [1, 1, 1, 1].
+    '''
+
     background_normal = StringProperty('data/images/button.png')
     '''Background image of the button used for default graphical representation,
     when the button is not pressed.
@@ -76,6 +87,18 @@ class Button(Label):
     default to 'data/images/button_pressed.png'
     '''
 
+    border = ListProperty([16, 16, 16, 16])
+    '''Border used for :class:`~kivy.graphics.vertex_instructions.BorderImage`
+    graphics instruction, used itself for :data:`background_normal` and
+    :data:`background_down`. Can be used when using custom background.
+
+    It must be a list of 4 value: (top, right, bottom, left). Read the
+    BorderImage instruction for more information about how to play with it.
+
+    :data:`border` is a :class:`~kivy.properties.ListProperty`, default to (16,
+    16, 16, 16)
+    '''
+
     def __init__(self, **kwargs):
         super(Button, self).__init__(**kwargs)
         self.register_event_type('on_press')
