@@ -2,25 +2,23 @@
 Image
 =====
 
-Use an image as a Widget. ::
+The :class:`Image` widget is used to display an image. ::
 
     wimg = Image(source='mylogo.png')
 
 Asynchronous loading
 --------------------
 
-If you want to load your image in an asynchronous way, you may use the
-:class:`AsyncImage` class. You can use it for loading external images on the
-web. ::
+To load an image asynchronously (for example from an external webserver), use 
+the :class:`AsyncImage` subclass ::
 
-    image = AsyncImage(source='http://mywebsite.com/logo.png')
+    aimg = AsyncImage(source='http://mywebsite.com/logo.png')
 
 Alignement
 ----------
 
 By default, the image is centered and fitted inside the widget bounding box.
-If you don't want that, we suggest you to inherit from :class:`Image`, and
-create your own style.
+If you don't want that, you can inherit from Image and create your own style.
 
 For example, if you want your image to take the same size of your widget, you
 can do ::
@@ -44,11 +42,10 @@ And in your kivy language file, you can do ::
 __all__ = ('Image', 'AsyncImage')
 
 from kivy.uix.widget import Widget
-from kivy.cache import Cache
 from kivy.core.image import Image as CoreImage
 from kivy.resources import resource_find
 from kivy.properties import StringProperty, ObjectProperty, ListProperty, \
-        AliasProperty, BooleanProperty
+        AliasProperty, BooleanProperty, NumericProperty
 from kivy.loader import Loader
 
 
@@ -90,7 +87,7 @@ class Image(Widget):
 
     mipmap = BooleanProperty(False)
     '''Indicate if you want OpenGL mipmapping to be apply on the texture or not.
-    Read :ref:`mipmap` for more informations.
+    Read :ref:`mipmap` for more information.
 
     .. versionadded:: 1.0.7
 
@@ -118,8 +115,8 @@ class Image(Widget):
 
     allow_stretch = BooleanProperty(False)
     '''If True, the normalized image size will be maximized to fit in the image
-    box. Otherwise, if the box is too higher, the image will be not strech more
-    that 1:1 pixels
+    box. Otherwise, if the box is too tall, the image will not be streched more
+    than 1:1 pixels
 
     .. versionadded:: 1.0.7
 
@@ -127,6 +124,29 @@ class Image(Widget):
     default to False
     '''
 
+    keep_ratio = BooleanProperty(True)
+    '''If False along with allow_stretch being True, the normalized image
+    size will be maximized to fit in the image box disregarding the aspect
+    ratio of the image.
+    Otherwise, if the box is too tall, the image will not be streched more
+    than 1:1 pixels
+
+    .. versionadded:: 1.0.8
+
+    :data:`keep_ratio` is a :class:`~kivy.properties.BooleanProperty`,
+    default to True
+    '''
+
+    anim_delay = NumericProperty(.25)
+    '''Delay of animation if the image is sequenced (like animated gif).
+    If the anim_delay is set to -1, the animation will be stopped.
+
+    .. versionadded:: 1.0.8
+
+    :data:`anim_delay` is a :class:`~kivy.properties.NumericProperty`, default
+    to .25 (4 FPS)
+    '''
+
     def get_norm_image_size(self):
         if not self.texture:
             return self.size
@@ -136,6 +156,8 @@ class Image(Widget):
 
         # ensure that the width is always maximized to the containter width
         if self.allow_stretch:
+            if not self.keep_ratio:
+                return w, h
             iw = w
         else:
             iw = min(w, tw)
@@ -165,6 +187,7 @@ class Image(Widget):
     '''
 
     def __init__(self, **kwargs):
+        self._coreimage = None
         super(Image, self).__init__(**kwargs)
         self.bind(source=self.texture_update,
                   mipmap=self.texture_update)
@@ -179,18 +202,28 @@ class Image(Widget):
             if filename is None:
                 return
             mipmap = self.mipmap
-            uid = '%s|%s' % (filename, mipmap)
-            texture = Cache.get('kv.texture', uid)
-            if not texture:
-                image = CoreImage(filename, mipmap=mipmap)
-                texture = image.texture
-                Cache.append('kv.texture', uid, texture)
-            self.texture = texture
+            if self._coreimage is not None:
+                self._coreimage.unbind(on_texture=self._on_tex_change)
+            self._coreimage = ci = CoreImage(filename, mipmap=mipmap,
+                    anim_delay=self.anim_delay)
+            ci.bind(on_texture=self._on_tex_change)
+            self.texture = ci.texture
+
+    def on_anim_delay(self, instance, value):
+        if self._coreimage is None:
+            return
+        self._coreimage.anim_delay = value
+        if value < 0:
+            self.anim_reset(False)
 
     def on_texture(self, instance, value):
         if value is not None:
             self.texture_size = list(value.size)
 
+    def _on_tex_change(self, *largs):
+        # update texture from core image
+        self.texture = self._coreimage.texture
+
 
 class AsyncImage(Image):
     '''Asynchronous Image class, see module documentation for more information.
@@ -211,10 +244,11 @@ class AsyncImage(Image):
                 value = resource_find(value)
             self._coreimage = image = Loader.image(value)
             image.bind(on_load=self.on_source_load)
+            image.bind(on_texture=self._on_tex_change)
             self.texture = image.texture
 
     def on_source_load(self, value):
-        image = self._coreimage
+        image = self._coreimage.image
         if not image:
             return
         self.texture = image.texture
@@ -223,3 +257,5 @@ class AsyncImage(Image):
         proto = filename.split('://', 1)[0]
         return proto in ('http', 'https', 'ftp')
 
+    def _on_tex_change(self, *largs):
+        self.texture = self._coreimage.texture
